@@ -172,4 +172,26 @@ sub validate_model_names {
 }
 
 1;
+__END__
+
+=head1 NAME
+
+OpenResty::Handler::Action - The action handler for OpenResty
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+This OpenResty handler class implements the Action API, i.e., the C</=/action/*> stuff.
+
+=head1 METHODS
+
+=head1 AUTHORS
+
+chaoslawful (王晓哲) C<< <chaoslawful at gmail dot com> >>,
+Agent Zhang (agentzh) C<< <agentzh@gmail.com >>
+
+=head1 SEE ALSO
+
+L<OpenResty::Handler::Model>, L<OpenResty::Handler::Role>, L<OpenResty::Handler::View>, L<OpenResty::Handler::Feed>, L<OpenResty::Handler::Version>, L<OpenResty::Handler::Captcha>, L<OpenResty::Handler::Login>, L<OpenResty>.
 
