@@ -39,7 +39,7 @@ sub get_feeds {
     my ($self, $openresty, $params) = @_;
     my $select = OpenResty::SQL::Select->new(
         qw< name description >
-    )->from('_feeds');
+    )->from('_feeds')->order_by('id');
     return $openresty->select("$select", { use_hash => 1 });
 }
 
